pub struct Dictionary {
pub index: Vec<IndexEntry>,
pub records: Vec<TagRecord>,
pub strings: Vec<u8>,
}Expand description
Root archived object in the .dmap file body.
Fields
index: Vec<IndexEntry>records: Vec<TagRecord>strings: Vec<u8>Trait Implementations
Sourceimpl Archive for Dictionary
impl Archive for Dictionary
Sourcetype Archived = ArchivedDictionary
type Archived = ArchivedDictionary
The archived representation of this type. Read more
Sourcetype Resolver = DictionaryResolver
type Resolver = DictionaryResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.
Sourceimpl Debug for Dictionary
impl Debug for Dictionary
Sourceimpl<__D: Fallible + ?Sized> Deserialize<Dictionary, __D> for Archived<Dictionary>where
Vec<IndexEntry>: Archive,
Archived<Vec<IndexEntry>>: Deserialize<Vec<IndexEntry>, __D>,
Vec<TagRecord>: Archive,
Archived<Vec<TagRecord>>: Deserialize<Vec<TagRecord>, __D>,
Vec<u8>: Archive,
Archived<Vec<u8>>: Deserialize<Vec<u8>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<Dictionary, __D> for Archived<Dictionary>where
Vec<IndexEntry>: Archive,
Archived<Vec<IndexEntry>>: Deserialize<Vec<IndexEntry>, __D>,
Vec<TagRecord>: Archive,
Archived<Vec<TagRecord>>: Deserialize<Vec<TagRecord>, __D>,
Vec<u8>: Archive,
Archived<Vec<u8>>: Deserialize<Vec<u8>, __D>,
Sourcefn deserialize(&self, deserializer: &mut __D) -> Result<Dictionary, __D::Error>
fn deserialize(&self, deserializer: &mut __D) -> Result<Dictionary, __D::Error>
Deserializes using the given deserializer